"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.downloadFileToDestination = void 0;
const fs = __importStar(require("fs"));
const path_1 = __importDefault(require("path"));
const follow_redirects_1 = __importDefault(require("follow-redirects"));
const { https } = follow_redirects_1.default;
/**
 * Downloads the file at the given URL
 * @param url the URL to the file to be downloaded
 */
const downloadFile = (url) => {
    return new Promise((resolve, reject) => {
        const data = [];
        console.log(`Downloading file at url ${url}`);
        https
            .request(url, connection => {
            connection.on('data', (chunk) => data.push(chunk));
            connection.on('end', () => {
                const bytes = Buffer.concat(data);
                resolve({
                    arrayBuffer: () => Promise.resolve(bytes),
                });
            });
            connection.on('error', e => reject(e));
        })
            .on('error', e => reject(e))
            .end();
    });
};
/**
 * Creates the destination directory if it exists. You can pass an entire file
 * path to it but it will only create the directory part of it.
 * @param destination destination you want to create the directory for
 */
function createDirectory(destination) {
    const dir = path_1.default.dirname(destination);
    if (!fs.existsSync(dir)) {
        fs.mkdirSync(dir, { recursive: true });
    }
}
/**
 * Downloads the file at `url` and saves it to `destination`
 * @param url the URL of the file to download
 * @param destination where to save the file
 */
const downloadFileToDestination = (url, destination) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const file = yield downloadFile(url);
        const bytes = yield file.arrayBuffer();
        createDirectory(destination);
        fs.writeFileSync(destination, bytes);
    }
    catch (error) {
        console.error(`Attempted to download a file at ${url} but the download failed: `, error);
    }
});
exports.downloadFileToDestination = downloadFileToDestination;
